package org.example.lostpet5;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class BBDD extends SQLiteOpenHelper{
	
	private static final String DB_NAME="lostPetDB.db3";
	
	private static final String CREATE_TABLE_DATOS="" +
			"CREATE TABLE Datos ( " +
				"id INTEGER PRIMARY KEY AUTOINCREMENT," +
				"tipo INTEGER DEFAULT 0," +
				"sexo INTEGER DEFAULT 0," +
				"tamanyo INTEGER DEFAULT 0," +
				"raza TEXT DEFAULT ''," +
				"color TEXT DEFAULT ''," +
				"carac TEXT DEFAULT ''," +
				"descripcion TEXT DEFAULT ''," +
				"fecha CHAR(19)," +
				"lat REAL DEFAULT 0," +
				"lng REAL DEFAULT 0," +
				"id_servidor INTEGER DEFAULT 0 " +
			")";
	
	private static final String CREATE_TABLE_IMAGENES="" +
			"CREATE TABLE Imagenes( " +
				"id INTEGER PRIMARY KEY AUTOINCREMENT," +
				"ruta TEXT," +
				"estado INTEGER DEFAULT 0, " +
				"id_dato INTEGER," +				
				"FOREIGN KEY (id_dato) REFERENCES Datos(id) ON DELETE CASCADE" +				
			")";
	
	
	public BBDD(Context contex) {
		super(contex, DB_NAME, null, 1);		
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		db.execSQL(CREATE_TABLE_DATOS);
		db.execSQL(CREATE_TABLE_IMAGENES);		
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		db.execSQL("PRAGMA foreign_keys = ON");
		db.execSQL("DROP TABLE IF EXISTS Datos");		
	}
	
	public long getLastID(){
		SQLiteDatabase db=getReadableDatabase();
		Cursor c=db.rawQuery("SELECT last_insert_rowid() AS last", null);
		c.moveToFirst();
		long res=c.getLong(c.getColumnIndex("last"));
		c.close();
		db.close();
		return res;
	}
	
	public long insertarDatos(int tipo, int sexo, int tamanyo, String raza, String color, String carac, String descripcion, String fecha, double lat, double lng){
		ContentValues nuevo=new ContentValues();
		nuevo.put("tipo", tipo);
		nuevo.put("sexo", sexo);
		nuevo.put("tamanyo", tamanyo);
		nuevo.put("raza", raza);
		nuevo.put("color", color);
		nuevo.put("carac", carac);
		nuevo.put("descripcion", descripcion);
		nuevo.put("fecha", fecha);
		nuevo.put("lat", lat);
		nuevo.put("lng", lng);
		SQLiteDatabase db=getReadableDatabase();
		long res=db.insert("Datos", null, nuevo);
		db.close();
		return res;		
	}
	
	public boolean actualizarPosicion(long id, double lat, double lng){
		ContentValues modificar=new ContentValues();
		modificar.put("lat", lat);
		modificar.put("lng", lng);
		SQLiteDatabase db=getReadableDatabase();
		String args[]=new String[]{id+""};
		int res=db.update("Datos",modificar, "id=?", args);
		db.close();
		return (res>0);
	}	
	
	public boolean actualizarIdServidor(long id, long id_servidor){
		ContentValues modificar=new ContentValues();
		modificar.put("id_servidor", id_servidor);
		SQLiteDatabase db=getReadableDatabase();
		String args[]=new String[]{id+""};
		int res=db.update("Datos", modificar, "id=?", args);
		db.close();
		return (res>0);
	}	
	
	public boolean actualizarEstadoImagen(long id){
		ContentValues modificar=new ContentValues();
		modificar.put("estado", 1);
		SQLiteDatabase db=getReadableDatabase();
		String args[]=new String[]{id+""};
		int res=db.update("Imagenes", modificar, "id=?", args);
		db.close();
		return (res>0);
	}
	
	public long eliminarDato(long id){
		SQLiteDatabase db=getReadableDatabase();
		db.execSQL("PRAGMA foreign_keys = ON");
		String args[]=new String[]{(id+"")};
		int res=db.delete("Datos", "id=?", args);
		db.close();
		return (long)res;
	}
	
	public long insertarImagen(long idDato, String ruta){
		ContentValues nuevo=new ContentValues();
		nuevo.put("id_dato", idDato);
		nuevo.put("ruta", ruta);
		SQLiteDatabase db=getReadableDatabase();
		long res=db.insert("Imagenes", null, nuevo);
		db.close();
		return res;
	}
	
	public List<Datos> obtenerDatos(){
		SQLiteDatabase db=getReadableDatabase();
		Cursor c=db.rawQuery("SELECT id FROM Datos", null);
		List<Datos> res=new ArrayList<Datos>();
		while(c.moveToNext()){
			res.add(obtenerDato(c.getLong(c.getColumnIndex("id"))));
		}
		c.close();
		db.close();
		return res;		
	}
	
	public Datos obtenerDato(long id){
		SQLiteDatabase db=getReadableDatabase();
		Cursor c=db.rawQuery("SELECT * FROM Datos where id="+id+" ", null);
		c.moveToFirst();
		Datos d=new Datos();
		d.setId(c.getLong(c.getColumnIndex("id")));
		d.setTipo(c.getInt(c.getColumnIndex("tipo")));
		d.setSexo(c.getInt(c.getColumnIndex("sexo")));
		d.setTamanyo(c.getInt(c.getColumnIndex("tamanyo")));
		d.setRaza(c.getString(c.getColumnIndex("raza")));
		d.setColor(c.getString(c.getColumnIndex("color")));
		d.setCaracteristicas(c.getString(c.getColumnIndex("carac")));
		d.setDescripcion(c.getString(c.getColumnIndex("descripcion")));
		String fecha=c.getString(c.getColumnIndex("fecha"));
		try {
			d.setFecha(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss",Locale.GERMAN).parse(fecha));
		} catch (ParseException e) {
			d.setFecha(new Date());
		}
		d.setLat(c.getDouble(c.getColumnIndex("lat")));
		d.setLng(c.getDouble(c.getColumnIndex("lng")));
		d.setIdServidor(c.getLong(c.getColumnIndex("id_servidor")));
		d.setImagenes(obtenerImagenes(d.getId()));
		c.close();
		db.close();
		return d;
	}
	
	public double[] obtenerPosicion(long id){
		SQLiteDatabase db=getReadableDatabase();
		Cursor c=db.rawQuery("SELECT lat,lng FROM Datos where id_dato="+id+" ", null);
		c.moveToFirst();
		double lat=c.getDouble(c.getColumnIndex("lat"));
		double lng=c.getDouble(c.getColumnIndex("lng"));
		c.close();
		db.close();
		double res[]={lat,lng};
		return res;
	}
	
	public List<Imagen> obtenerImagenes(long id_dato){
		SQLiteDatabase db=getReadableDatabase();
		Cursor c=db.rawQuery("SELECT * FROM Imagenes WHERE id_dato="+id_dato+" ", null);
		List<Imagen> res=new ArrayList<Imagen>();
		while(c.moveToNext()){
			long id=c.getLong(c.getColumnIndex("id"));
			String ruta=c.getString(c.getColumnIndex("ruta"));
			int estado=c.getInt(c.getColumnIndex("estado"));
			res.add(new Imagen(id,ruta,estado));
		}
		c.close();
		db.close();
		return res;
	}
	
}

