package org.example.lostpet5;

import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.concurrent.ExecutionException;

import org.apache.http.NameValuePair;
import org.apache.http.message.BasicNameValuePair;
import org.json.JSONException;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.Uri;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.TextView;

public class Envio extends Activity{

	List<Datos> datos;
	MiArrayAdapter adapter;	
	Datos dato;	
	Activity actividad;	
	
	@Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.actividad=this;
        
        setContentView(R.layout.envio);        
        final ListView lw=(ListView) findViewById(R.id.listview);
        
        datos=Datos.obtenerDatos(getApplicationContext());
        
        adapter=new MiArrayAdapter(this,datos);
        lw.setAdapter(adapter);
        
        lw.setOnItemClickListener(new OnItemClickListener() {
			@Override
			public void onItemClick(AdapterView<?> parent, View view, int position, long ID) {
				dato=datos.get(position);
				Intent intent=new Intent(actividad,Mapa.class);	 
				Log.e("Lat",dato.getLat()+" "+dato.getLng());
	        	intent.putExtra("lat",dato.getLat());
	        	intent.putExtra("lng",dato.getLng());
	        	Envio.this.startActivityForResult(intent,GLOBALES.RESULTADO_MAPA);
			}
		});
        
        int estado=Utilidades.estadoRedes(this);
        
        //Si no viene del menu
        if(getIntent().getExtras()!=null &&  getIntent().getExtras().containsKey("id") && estado>0){
        	long id=getIntent().getLongExtra("id", 0);
        	for(Datos d : datos){
        		if(d.getId()==id){
        			dato=d;
        			Intent intent=new Intent(this,Mapa.class);        	
                	this.startActivityForResult(intent,GLOBALES.RESULTADO_MAPA);
                	break;
        		}
        	}        	
        }
    }	
	
	
	
	public void eliminarEnvio(final int position){
		AlertDialog.Builder adb=new AlertDialog.Builder(this);
        adb.setTitle(R.string.title_borrar_envio);
        adb.setMessage(R.string.msg_borrar_envio);
        adb.setNegativeButton(R.string.btn_no_borrar_envio, null);
        adb.setPositiveButton(R.string.btn_yes_borrar_envio, new AlertDialog.OnClickListener() {
            public void onClick(DialogInterface dialog, int which) {
            	eliminarDatosEnvio(datos.get(position));
            	datos.remove(position);
            	adapter.notifyDataSetChanged();
            }
        });
        adb.show();
    }	
	
	public void eliminarDatosEnvio(Datos dato){		
		for(Imagen img : dato.getImagenes()){
			Ficheros.eliminarImagen(img.getRuta());
		}
		dato.eliminarDato(getApplicationContext());
	}
	
	private void subirDato(int position){
		this.dato=datos.get(position);
		int estado=Utilidades.estadoRedes(this);
		SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(this);
		final String usuario=pref.getString("pref_usuario", "");		
		String pass=pref.getString("pref_contrasenya","");
		String servidor=pref.getString("pref_servidor", "");
		boolean tipo=pref.getBoolean("pref_conexion",false);
		String puerto=pref.getString("pref_puerto", "");
		
		final String url="http://"+servidor+":"+puerto+GLOBALES.URL;	
		
		if(estado==0){
			mostrarAlertas(0);			
		}
		else if(estado==1 && tipo){
			mostrarAlertas(1);			
		}
		else if(servidor.length()==0){
			mostrarAlertas(2);			
		}
		else if(usuario.length()>0 && pass.length()==0){
			mostrarAlertas(3);			
		}		
		else{			
			try {
				//No esta guardado en el servidor
				if(dato.getIdServidor()==0){
					String json = dato.toJSON();
					List<NameValuePair> pares = new ArrayList<NameValuePair>();
					pares.add(new BasicNameValuePair("operacion","guardar_dato"));
					pares.add(new BasicNameValuePair("usuario",usuario));			
					pares.add(new BasicNameValuePair("dato",json));
					Conexion con=new Conexion(this,pares);
					
					String res=con.execute(url,"post").get();					
					if(Utilidades.esNumero(res)){
						dato.setIdServidor(Long.parseLong(res));
						dato.modificarIdServidor(getApplicationContext());
						if(subirImagenes(url,dato.getIdServidor(),dato.getImagenes())){
							borrarDatos(position);
							mostrarAlertas(4);							
						}
					}
				}
				//Si esta guardado en el servidor
				else{					
					if(subirImagenes(url,dato.getIdServidor(),dato.getImagenes())){
						borrarDatos(position);
						mostrarAlertas(4);						
					}
				}
			} catch (InterruptedException e) {
				e.printStackTrace();
			} catch (ExecutionException e) {
				e.printStackTrace();
			} catch(NullPointerException e){
				e.printStackTrace();
			} catch (JSONException e1) {			
				e1.printStackTrace();
			}		
		}
	}
	
	private boolean subirImagenes(String url, long id, List<Imagen> imagenes) throws InterruptedException, ExecutionException, NullPointerException{
		for(Imagen img : imagenes){			
			if(img.getEstado()==0){
				Conexion con=new Conexion(this,null);
				url+="?operacion=guardar_img&id="+id;				
				String res=con.execute(url,"file",img.getRuta()).get();				
				if(res.equals("ok")){
					img.setEstado(1);
					img.modificarEstado(getApplicationContext());
					Thread.sleep(1000);
				}
				else{
					throw new InterruptedException();
				}
			}			
		}
		return true;
	}
	
	private void borrarDatos(int position){
		Datos dato=datos.get(position);
		for(Imagen img : dato.getImagenes()){
			Ficheros.eliminarImagen(img.getRuta());
		}
		dato.eliminarDato(getApplicationContext());
		datos.remove(position);		
		adapter.notifyDataSetChanged();
	}
	
	public void mostrarAlertas(int tipo){		
		switch(tipo){
			case 0:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_borrar);
		        adb.setMessage(R.string.msg_borrar);
		        adb.setNeutralButton(R.string.btn_yes_borrar, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 1:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_borrar);
		        adb.setMessage(R.string.msg_borrar);
		        adb.setNeutralButton(R.string.btn_yes_borrar, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 2:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_borrar);
		        adb.setMessage(R.string.msg_borrar);
		        adb.setNeutralButton(R.string.btn_yes_borrar, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 3:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_borrar);
		        adb.setMessage(R.string.msg_borrar);
		        adb.setNeutralButton(R.string.btn_yes_borrar, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 4:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_enviado);
		        adb.setMessage(R.string.msg_enviado);
		        adb.setNeutralButton(R.string.btn_yes_enviado, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
		}
	}
	
	
	@Override
	public void onActivityResult(final int requestCode,final int resultCode, final Intent data) {
		if(resultCode==GLOBALES.RESULTADO_MAPA){
			double lat=data.getDoubleExtra("resLat", 0);
			double lng=data.getDoubleExtra("resLng", 0);
			if(lat!=0 && lng!=0){
				dato.setLat(lat);
				dato.setLng(lng);
				dato.modificarPosicion(getApplicationContext());
			}
		}
	}
	
	@Override
	public void onBackPressed(){
		this.setResult(GLOBALES.SALIR_APLICACION);
		this.finish();		
	}
	
	private class MiArrayAdapter extends ArrayAdapter<Datos>{
		
		private final Context context;
		private final List<Datos> datos;
		
		public MiArrayAdapter(Context context,List<Datos> values){
			super(context,R.layout.lista,values);
			this.context=context;
			this.datos=values;
		}
		
		@Override
		public View getView(final int position,View convertView, ViewGroup parent){
			LayoutInflater inflater=(LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
			View rootView=inflater.inflate(R.layout.lista, parent, false);
			ImageView img=(ImageView) rootView.findViewById(R.id.imagen_lista);
			TextView textFecha=(TextView) rootView.findViewById(R.id.texto_inf_lista);			
			Button btn=(Button) rootView.findViewById(R.id.boton_lista);
			btn.setOnClickListener(new OnClickListener(){
				@Override
				public void onClick(View v) {					
					subirDato(position);					
				}				
			});
			btn.setFocusable(false);
			ImageButton img_btn=(ImageButton) rootView.findViewById(R.id.boton_borrar);
			img_btn.setOnClickListener(new OnClickListener(){
				@Override
				public void onClick(View v) {
					eliminarEnvio(position);
				}				
			});
			img_btn.setFocusable(false);
			Datos d=datos.get(position);
			if(d.getImagenes().size()>0){
				img.setScaleType(ImageView.ScaleType.CENTER_CROP); 
				img.setImageURI(Uri.fromFile(new File(Ficheros.obtenerRutaMiniatura(d.getImagenes().get(0).getRuta()))));				
			}
			else{
				img.setImageResource(android.R.drawable.ic_menu_gallery); 
			}
			
			String fecha=new SimpleDateFormat("dd-MM-yyyy HH:mm",Locale.GERMAN).format(d.getFecha()).toString();
			textFecha.setText(fecha);
			return rootView;
		}
		
			
	}

	
	
	
}
