package org.example.lostpet5;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.concurrent.ExecutionException;

import org.apache.http.NameValuePair;
import org.apache.http.message.BasicNameValuePair;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentPagerAdapter;
import android.support.v4.view.ViewPager;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends FragmentActivity{
	
	
	SectionsPagerAdapter mSectionsPagerAdapter;
	ViewPager mViewPager;
	private Camara camara;
	private Formulario formulario;
	private Sonido sonido;	
	private Virtual virtual;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);		
		mSectionsPagerAdapter = new SectionsPagerAdapter(getSupportFragmentManager());
		mViewPager = (ViewPager) findViewById(R.id.pager);
		mViewPager.setAdapter(mSectionsPagerAdapter);
		//Evita que se destruyan los fragments
		mViewPager.setOffscreenPageLimit(4);	
		
		//Fragmentos
		camara=new Camara();
		formulario=new Formulario();
		sonido=new Sonido();
		virtual=new Virtual();
		
		//Borra fotos temporales
		Ficheros.BorrarImagenesTemp();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
	   		case R.id.settings:{
	   			Intent intent=new Intent(this,PreferenciasActivity.class);
	   			startActivity(intent); 
	   			break;
	   		}
	   		case R.id.send:{
	   			mostrarMapa();
	   			break;
	   		}
	   		case R.id.help:{
	   			Toast toast = Toast.makeText(this.getApplicationContext(), this.getResources().getString(R.string.toastcamara), Toast.LENGTH_SHORT);
	   			toast.show();
	   			break;
	   		}
	   		case R.id.pendiente:{
	   			Intent intent=new Intent(this,Envio.class);
	   			startActivityForResult(intent,0);
	   			break;
	   		}	   		
		}
		return true;
	}
	
	@Override
	public void onActivityResult(final int requestCode,final int resultCode, final Intent data) {    
		if(resultCode==GLOBALES.SALIR_APLICACION){			
			finalizar();		
		}
		else if(resultCode!=Activity.RESULT_CANCELED){
			switch(requestCode){				
				case GLOBALES.SOLICITUD_HACER_FOTOGRAFIA:{					
					
				}
				case GLOBALES.SELECCIONAR_IMAGEN:{
					camara.onMyActivityResult(requestCode, resultCode, data);
					break;
				}
				case GLOBALES.RECONOZIMINETO_DE_VOZ_REQUEST_CODE:{
					sonido.onMyActivityResult(requestCode, resultCode, data);
					break;
				}
			}	    	
		}
	}	
	
	public void mostrarMapa(){
		if(camara.esVacio() && formulario.esVacio() && sonido.esVacio()){
			mostrarAlerta(0);
		}		
		else if(!formulario.esVacio() && formulario.esCompleto()!=0){
			if(formulario.esCompleto()==1){
				mostrarAlerta(1);
			}
			else if(formulario.esCompleto()==2){
				mostrarAlerta(2);
			} 
			else if(formulario.esCompleto()==3){
				mostrarAlerta(3);
			}
		}
		else{
			long id=guardarEnviar();
			Intent intent=new Intent(this,Envio.class);
			intent.putExtra("id", id);
			this.startActivityForResult(intent,0);
		}
	}
	
	public long guardarEnviar(){
		BBDD bd=new BBDD(this.getApplicationContext());
		long newId=bd.insertarDatos(formulario.getTipo(),formulario.getSexo(), formulario.getTamanyo(), formulario.getRaza(),
				formulario.getColor(), formulario.getCaracteristicas(), sonido.getDescripcion(),
				new SimpleDateFormat("yyyy-MM-dd HH:mm:ss",Locale.GERMAN).format(new Date()), 0, 0);
		
		for(String ruta : camara.getImagenes()){
			File f;
			try {
				f = Ficheros.crearFicheroImagenExterno(newId);
				String nuevaRuta=f.getAbsolutePath();
				Ficheros.moverFichero(ruta,nuevaRuta);
				bd.insertarImagen(newId,nuevaRuta);
			} catch (IOException e) {
				e.printStackTrace();
			}			
		}		
		return newId;
	}
	
	private void finalizar(){
		this.finish();		
	}
	
	public void mostrarAlerta(int code){
		switch(code){
			case 0:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_sin_datos);
		        adb.setMessage(R.string.msg_sin_datos);
		        adb.setNeutralButton(R.string.btn_yes_sin_datos, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
		        break;
			}
			case 1:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_error_tamanyo);
		        adb.setMessage(R.string.msg_error_tamanyo);
		        adb.setNeutralButton(R.string.btn_yes_error_tamanyo, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 2:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_error_color);
		        adb.setMessage(R.string.msg_error_color);
		        adb.setNeutralButton(R.string.btn_yes_error_color, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 3:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_error_carac);
		        adb.setMessage(R.string.msg_error_carac);
		        adb.setNeutralButton(R.string.btn_yes_error_carac, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 4:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_user);
		        adb.setMessage(R.string.msg_user);
		        adb.setNeutralButton(R.string.btn_yes_user, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 5:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_no_user);
		        adb.setMessage(R.string.msg_no_user);
		        adb.setNeutralButton(R.string.btn_yes_no_user, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 6:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_error_no_user);
		        adb.setMessage(R.string.msg_error_no_user);
		        adb.setNeutralButton(R.string.btn_yes_error_no_user, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
			case 7:{
				AlertDialog.Builder adb=new AlertDialog.Builder(this);
		        adb.setTitle(R.string.title_error_server);
		        adb.setMessage(R.string.msg_error_server);
		        adb.setNeutralButton(R.string.btn_yes_error_server, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	Intent intent=new Intent(MainActivity.this,PreferenciasActivity.class);
			   			startActivity(intent);
			   			dialog.cancel();
		            }
		        });
		        adb.show();
				break;
			}
		}
	}
	
	public class SectionsPagerAdapter extends FragmentPagerAdapter {

		public SectionsPagerAdapter(FragmentManager fm) {
			super(fm);
		}

		@Override
		public Fragment getItem(int position) {
			if(position==0){
				return camara;
			}
			else if(position==1){
				return formulario;
			}
			else if(position==2){
				return sonido;
			}
			else{
				return virtual;				
			}					
		}

		@Override
		public int getCount() {
			return 4;
		}

		@Override
		public CharSequence getPageTitle(int position) {
			Locale l = Locale.getDefault();
			switch (position) {
			case 0:
				return getString(R.string.title_section1).toUpperCase(l);
			case 1:
				return getString(R.string.title_section2).toUpperCase(l);
			case 2:
				return getString(R.string.title_section3).toUpperCase(l);
			case 3:
				return getString(R.string.title_section4).toUpperCase(l);
			}
			return null;
		}
	}
}
